#include "DetectorConstruction.hh"

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

DetectorConstruction::DetectorConstruction()
{}  

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

DetectorConstruction::~DetectorConstruction()
{}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

// Mandatory implementation of Construct method
G4VPhysicalVolume* DetectorConstruction::Construct()

{
  DefineMaterials();
  return ConstructDetector();
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

void DetectorConstruction::DefineMaterials()
{ 
  G4String name, symbol;             
  G4double density;            
  
  G4int ncomponents, natoms;
  G4double z, a;
  G4double fractionmass;
  
  // Define Elements  
  // Example: G4Element* Notation  = new G4Element ("Element", "Notation", z, a);
  G4Element*   H  = new G4Element ("Hydrogen", "H", 1. ,  1.01*g/mole);
  G4Element*   N  = new G4Element ("Nitrogen", "N", 7., 14.01*g/mole);
  G4Element*   O  = new G4Element ("Oxygen"  , "O", 8. , 16.00*g/mole);
 
  // Define Material
  
  // Case 1: chemical molecule  
  // Water 
  density = 1.000*g/cm3;
  G4Material* H2O = new G4Material(name="H2O"  , density, ncomponents=2);
  H2O->AddElement(H, natoms=2);
  H2O->AddElement(O, natoms=1);
  
  // Case 2: mixture by fractional mass.
  // Air
  density = 1.290*mg/cm3;
  G4Material* Air = new G4Material(name="Air"  , density, ncomponents=2);
  Air->AddElement(N, fractionmass=0.7);
  Air->AddElement(O, fractionmass=0.3);

  // Vaccum standard definition...
  density = universe_mean_density;
  G4Material* vacuum = new G4Material(name="Vacuum", z=1., a=1.01*g/mole,
	density);

  // Display list of defined materials
  G4cout << G4endl << *(G4Material::GetMaterialTable()) << G4endl;

  // Default materials in setup.
  defaultMaterial = Air;
  waterMaterial = H2O;
  
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
G4VPhysicalVolume* DetectorConstruction::ConstructDetector()
{

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

  // MANDATORY MOTHER "WORLD" VOLUME
  
  WorldSizeX  = 50*micrometer; 
  WorldSizeY  = 50*micrometer; 
  WorldSizeZ  = 50*micrometer;

  //---Solid
  solidWorld = new G4Box("World",				     //its name
			   WorldSizeX/2,WorldSizeY/2,WorldSizeZ/2);  //its size
  

  //---Logic
  logicWorld = new G4LogicalVolume(solidWorld,	        //its solid
				   defaultMaterial,	//its material
				   "World");		//its name
  
  //---Physical
  physiWorld = new G4PVPlacement(0,			//no rotation
  				 G4ThreeVector(),	//at (0,0,0)
                                 "World",		//its name
                                 logicWorld,		//its logical volume
                                 NULL,			//its mother  volume
                                 false,			//no boolean operation
                                 0);			//copy number


  // TARGET VOLUME 

  solidTarget = new G4Sphere("Target",			//its name
			      0,10*micrometer,		        //its minRadius and maxRadius
			      0,2*M_PI,                 //its phiMin and deltaPhi
			      0,M_PI);                  //its thetaMin and deltaTheta
  

  logicTarget = new G4LogicalVolume(solidTarget,	//its solid
				   waterMaterial,	//its material
				   "Target");		//its name

  physiTarget = new G4PVPlacement(0,			//rotation
  				 G4ThreeVector(0,0,0),// transl
				 "Target",		//its name
                                 logicTarget,		//its logical volume
                                 physiWorld,		//its mother  volume
                                 false,			//no boolean operation
                                 0);			//copy number

 
  // Visualization attributes
  
  G4VisAttributes* worldVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,1.0)); //White
  worldVisAtt->SetVisibility(true);
  logicWorld->SetVisAttributes(worldVisAtt);
 
  G4VisAttributes* targetVisAtt= new G4VisAttributes(G4Colour(0,1.0,1.0)); //Blue
  targetVisAtt->SetForceSolid(true);
  targetVisAtt->SetVisibility(true);
  
  logicTarget->SetVisAttributes(targetVisAtt);

  // User Limits
  logicWorld->SetUserLimits(new G4UserLimits(1*micrometer));
  logicTarget->SetUserLimits(new G4UserLimits(1*micrometer));
 
  return physiWorld;
}
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....


