#include "EventAction.hh"

#include "RunAction.hh"

#include "G4Event.hh"
#include "G4EventManager.hh"
#include "G4TrajectoryContainer.hh"
#include "G4Trajectory.hh"
#include "G4VVisManager.hh"
#include "Randomize.hh"

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

// Specify run action object in argument
// Initialize a flag for trajectory drawing
EventAction::EventAction(RunAction* run)
  :Run(run),drawFlag("all")
{}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

EventAction::~EventAction()
{}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

void EventAction::BeginOfEventAction(const G4Event* /*evt*/)
{
// Dose is accessed through accessor and is set to zero at beginning of new event
  Run->SetDoseTarget(0);
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

void EventAction::EndOfEventAction(const G4Event* evt)
{  

// Dose is written in text file at the end of event

  if (Run->GetDoseTarget()>0) 
  {
	FILE* myFile;
	myFile=fopen("dose.txt","a");
	fprintf(myFile,"%e\n",float(Run->GetDoseTarget()) );
	fclose (myFile);
	
        G4cout << "   ===> The incident particle has reached the targeted cell :" << G4endl;
	G4cout << "   -----> total absorbed dose is (Gy) = " << Run->GetDoseTarget() << G4endl;
	G4cout << G4endl;
  }
  else
  {
	G4cout << "   ===> Sorry, the incident alpha particle has missed the targeted cell !" << G4endl;
	G4cout << G4endl;
  }

// Mandatory for trajectory drawing in vizualisation window

     if (G4VVisManager::GetConcreteInstance())
    {
      G4TrajectoryContainer * trajectoryContainer = evt->GetTrajectoryContainer();

      G4int n_trajectories = 0;
      if (trajectoryContainer) n_trajectories = trajectoryContainer->entries();
    
      for (G4int i=0; i<n_trajectories; i++) 
        { 
	  G4Trajectory* trj = (G4Trajectory*)((*(evt->GetTrajectoryContainer()))[i]);
	  if (drawFlag == "all")
	    { 
	      trj->DrawTrajectory(50);
	    }
	  else if ((drawFlag == "charged")&&(trj->GetCharge() != 0.))	    
	    {
	      trj->DrawTrajectory(50);
	    }
	} 
    }
    
}
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
